@@ -466,9 +466,10 @@ namespace giac {
   int vecteur2gsl_vector(const vecteur & v,gsl_vector * w,GIAC_CONTEXT); // no alloc
   int vecteur2gsl_vector(const_iterateur it,const_iterateur itend,gsl_vector * w,GIAC_CONTEXT);
   vecteur gsl_vector2vecteur(const gsl_vector * v);
+  int matrice2gsl_matrix(const matrice & m,int i0,int j0,int n1,int n2,bool transp,gsl_matrix * w,GIAC_CONTEXT);
   int matrice2gsl_matrix(const matrice & m,gsl_matrix * w,GIAC_CONTEXT);
   gsl_matrix * matrice2gsl_matrix(const matrice & m,GIAC_CONTEXT);
-  matrice gsl_matrix2matrice(const gsl_matrix * v);
+  matrice gsl_matrix2matrice(const gsl_matrix * v,bool transp=false);
   vecteur gsl_permutation2vecteur(const gsl_permutation * p,GIAC_CONTEXT);
 #endif // HAVE_LIBGSL
   
@@ -484,7 +485,7 @@ namespace giac {
 
   gen _cholesky(const gen & a,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_cholesky ;
-#ifndef KHICAS
+#if !defined KHICAS && !defined GIAC_HAS_STO_38
   // additions by L. Marohnić:
   struct log_output_redirect { // redirecting log output to string
     log_output_redirect(GIAC_CONTEXT) { old=logptr(ctx=contextptr)->rdbuf(buffer.rdbuf()); }
@@ -499,7 +500,7 @@ namespace giac {
   // LDL decomposition, inertia computation and solve_indef for fast system solving using the factorization
   bool ldl(matrice & a,std::vector<int> & perm,int mat_type,bool &sing,double time_limit,GIAC_CONTEXT);
 #ifdef HAVE_LIBLAPACK
-  bool solve_indef(double *A,double *WORK,int *IPIV,double *b,int N,int NRHS,int *p,int *n,int *z,GIAC_CONTEXT);
+  bool solve_indef(double *A,double **WORK,int *IPIV,double *b,int N,int NRHS,int *p,int *n,int *z);
 #endif
   bool solve_indef(matrice &A,const vecteur *b,vecteur &x,int *p,int *n,int *z,GIAC_CONTEXT);
   gen _ldl(const gen & a,GIAC_CONTEXT);
